@@ -14,14 +14,16 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_MATRIX_DOUBLE_H__
 #define __GSL_MATRIX_DOUBLE_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_check_range.h>
 #include <gsl/gsl_vector_double.h>
 
 #undef __BEGIN_DECLS
@@ -236,8 +238,6 @@ int gsl_matrix_get_col(gsl_vector * v, const gsl_matrix * m, const size_t j);
 int gsl_matrix_set_row(gsl_matrix * m, const size_t i, const gsl_vector * v);
 int gsl_matrix_set_col(gsl_matrix * m, const size_t j, const gsl_vector * v);
 
-extern int gsl_check_range ;
-
 /* inline functions if you are using GCC */
 
 #ifdef HAVE_INLINE
@@ -245,7 +245,7 @@ extern inline
 double
 gsl_matrix_get(const gsl_matrix * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VAL("first index out of range", GSL_EINVAL, 0) ;
@@ -262,7 +262,7 @@ extern inline
 void
 gsl_matrix_set(gsl_matrix * m, const size_t i, const size_t j, const double x)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VOID("first index out of range", GSL_EINVAL) ;
@@ -279,7 +279,7 @@ extern inline
 double *
 gsl_matrix_ptr(gsl_matrix * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
@@ -296,7 +296,7 @@ extern inline
 const double *
 gsl_matrix_const_ptr(const gsl_matrix * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
